@@ -96,8 +96,12 @@ class hhkit(object):
 		return self.variable_labels
 
 	# Here is a 'count' method for calculating household size
-	def egen(self, obj, operation, groupby, col, column_label='', include=None, exclude=None, varlabel=''):
-		df=obj.df
+	def egen(self, operation, groupby, col, obj=None, column_label='', include=None, exclude=None, varlabel='',
+				replacenanwith=None):
+		if obj is None:
+			df = self.df
+		else:
+			df=obj.df
 		include = self._make_include_exclude_series(df, include, exclude)
 
 		if column_label == '':
@@ -106,7 +110,12 @@ class hhkit(object):
 		result = df[include].groupby(groupby)[col].agg([operation])
 		result.rename(columns={operation:column_label}, inplace=True)
 		merged = pd.merge(df, result, left_on=groupby, right_index=True, how='left')
+
+		if replacenanwith is not None:
+			merged[column_label][merged[column_label].isnull()]=replacenanwith
+
 		self.df = merged
+
 		self.set_variable_labels(varlabeldict={column_label:varlabel,})
 		return merged
 
@@ -356,3 +365,30 @@ class hhkit(object):
 
 		else:
 			return False
+
+	def rr(self, column, dict_of_values, obj=None, include=None, exclude=None):
+
+		if obj is None:
+			df = self.df
+		else:
+			df=obj.df
+		include = self._make_include_exclude_series(df, include, exclude)
+		include2 = pd.Series(include, index=df.index)
+
+		# Requirement: new values must be the same type (string, numberic) as original values
+		df['_deleteme'] = df[column]
+
+		for k in dict_of_values:
+			if (str(k)=='nan'):
+				mask = pd.Series(df[column].isnull()) & include2
+				df['_deleteme'][mask] = dict_of_values[k]
+			else:
+				mask = pd.Series(df[column]==k) & include2
+				df['_deleteme'][mask] = dict_of_values[k]	
+
+		del df[column]
+		df[column] = df['_deleteme']
+		del df['_deleteme']
+		self.df[column] = df[column]
+
+		return df
